zmike pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=42480c5ebf32be52c3d5c5e484d5e8d5eac92fcb

commit 42480c5ebf32be52c3d5c5e484d5e8d5eac92fcb
Author: Mike Blumenkrantz <[email protected]>
Date:   Thu Mar 12 12:16:14 2020 -0400

    efl-wl: rename to efl.canvas.wl
    
    Summary:
    this is a canvas object so it needs to be in the canvas namespace
    
    Depends on D11475
    
    Reviewers: segfaultxavi, bu5hm4n
    
    Reviewed By: bu5hm4n
    
    Subscribers: cedric, #reviewers, #committers
    
    Tags: #efl
    
    Differential Revision: https://phab.enlightenment.org/D11476
---
 meson.build                                        |   2 +-
 .../efl_canvas_wl_test.c}                          |  10 +-
 .../efl_canvas_wl_test_stack.c}                    |  10 +-
 src/bin/efl_canvas_wl/meson.build                  |  13 ++
 src/bin/efl_wl/meson.build                         |  13 --
 .../Efl_Wl.h => efl_canvas_wl/Efl_Canvas_Wl.h}     |  66 +++++-----
 .../{efl_wl => efl_canvas_wl}/copiedfromweston.x   |   0
 src/lib/{efl_wl => efl_canvas_wl}/dmabuf.c         |   0
 src/lib/{efl_wl => efl_canvas_wl}/dmabuf.h         |   0
 .../efl_wl.c => efl_canvas_wl/efl_canvas_wl.c}     | 141 +++++++++++----------
 .../efl_wl.eo => efl_canvas_wl/efl_canvas_wl.eo}   |  46 +++----
 .../efl_canvas_wl_surface.eo}                      |   4 +-
 src/lib/{efl_wl => efl_canvas_wl}/meson.build      |  36 +++---
 src/lib/{efl_wl => efl_canvas_wl}/x11.x            |   0
 14 files changed, 171 insertions(+), 170 deletions(-)

diff --git a/meson.build b/meson.build
index 6ad434980c..bbf99d427a 100644
--- a/meson.build
+++ b/meson.build
@@ -331,7 +331,7 @@ subprojects = [
 ['ethumb'           ,[]                    ,  true,  true,  true, false, 
false, false, ['eina', 'efl', 'eo'], []],
 ['ethumb_client'    ,[]                    , false,  true,  true, false, 
false,  true, ['eina', 'efl', 'eo', 'ethumb'], []],
 ['elementary'       ,[]                    ,  true,  true,  true,  true,  
true,  true, ['eina', 'efl', 'eo', 'eet', 'evas', 'ecore', 'ecore-evas', 
'ecore-file', 'ecore-input', 'edje', 'ethumb-client', 'emotion', 'ecore-imf', 
'ecore-con', 'eldbus', 'efreet', 'efreet-mime', 'efreet-trash', 'eio'], 
['atspi']],
-['efl_wl'           ,['wl']                , false,  true,  true, false, 
false, false, ['eina', 'efl', 'eo', 'evas', 'ecore'], []],
+['efl_canvas_wl'    ,['wl']                , false,  true,  true, false, 
false, false, ['eina', 'efl', 'eo', 'evas', 'ecore'], []],
 ['elua'             ,['elua']              , false,  true,  true, false,  
true, false, ['eina', 'luajit'], []],
 ['ecore_wayland'    ,['wl-deprecated']     , false,  true, false, false, 
false, false, ['eina'], []],
 ['ecore_drm'        ,['drm-deprecated']    , false,  true, false, false, 
false, false, ['eina'], []],
diff --git a/src/bin/efl_wl/efl_wl_test.c 
b/src/bin/efl_canvas_wl/efl_canvas_wl_test.c
similarity index 90%
rename from src/bin/efl_wl/efl_wl_test.c
rename to src/bin/efl_canvas_wl/efl_canvas_wl_test.c
index b9f9f6b450..4bb7e616af 100644
--- a/src/bin/efl_wl/efl_wl_test.c
+++ b/src/bin/efl_canvas_wl/efl_canvas_wl_test.c
@@ -1,7 +1,7 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include "Efl_Wl.h"
+#include "Efl_Canvas_Wl.h"
 #include "Elementary.h"
 
 static Evas_Object *win;
@@ -23,7 +23,7 @@ focus_in(void *data, Evas *e EINA_UNUSED, Evas_Object *obj 
EINA_UNUSED, void *ev
 static Eina_Bool
 dostuff(void *data)
 {
-   exe = efl_wl_run(data, eina_strbuf_string_get(buf));
+   exe = efl_canvas_wl_run(data, eina_strbuf_string_get(buf));
    efl_event_callback_add(exe, EFL_TASK_EVENT_EXIT, del_handler, NULL);
    evas_object_focus_set(data, 1);
    return EINA_FALSE;
@@ -62,9 +62,9 @@ main(int argc, char *argv[])
    elm_win_autodel_set(win, 1);
    elm_policy_set(ELM_POLICY_QUIT, ELM_POLICY_QUIT_LAST_WINDOW_CLOSED);
 
-   o = efl_add(EFL_WL_CLASS, win);
-   efl_wl_aspect_set(o, 1);
-   efl_wl_minmax_set(o, 1);
+   o = efl_add(EFL_CANVAS_WL_CLASS, win);
+   efl_canvas_wl_aspect_set(o, 1);
+   efl_canvas_wl_minmax_set(o, 1);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_event_callback_add(o, EVAS_CALLBACK_CHANGED_SIZE_HINTS, 
hints_changed, win);
diff --git a/src/bin/efl_wl/efl_wl_test_stack.c 
b/src/bin/efl_canvas_wl/efl_canvas_wl_test_stack.c
similarity index 92%
rename from src/bin/efl_wl/efl_wl_test_stack.c
rename to src/bin/efl_canvas_wl/efl_canvas_wl_test_stack.c
index e6eaa34760..49849e07e8 100644
--- a/src/bin/efl_wl/efl_wl_test_stack.c
+++ b/src/bin/efl_canvas_wl/efl_canvas_wl_test_stack.c
@@ -1,7 +1,7 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include "Efl_Wl.h"
+#include "Efl_Canvas_Wl.h"
 #include "Elementary.h"
 
 static Evas_Object *win;
@@ -18,7 +18,7 @@ static unsigned int n;
 static Eina_Bool
 dostuff(void *data)
 {
-   efl_wl_run(data, cmds[n++]);
+   efl_canvas_wl_run(data, cmds[n++]);
    evas_object_focus_set(data, 1);
    return n != num_cmds;
 }
@@ -26,13 +26,13 @@ dostuff(void *data)
 static void
 prev_clicked(void *data, Evas_Object *obj EINA_UNUSED, void *event_info 
EINA_UNUSED)
 {
-   efl_wl_surface_prev(data);
+   efl_canvas_wl_surface_prev(data);
 }
 
 static void
 next_clicked(void *data, Evas_Object *obj EINA_UNUSED, void *event_info 
EINA_UNUSED)
 {
-   efl_wl_surface_next(data);
+   efl_canvas_wl_surface_next(data);
 }
 
 int
@@ -69,7 +69,7 @@ main(int argc, char *argv[])
    evas_object_show(next);
    elm_table_pack(o, next, 1, 0, 1, 1);
 
-   comp = efl_add(EFL_WL_CLASS, win);
+   comp = efl_add(EFL_CANVAS_WL_CLASS, win);
    evas_object_size_hint_min_set(comp, 640, 480);
    elm_table_pack(o, comp, 0, 1, 2, 1);
    evas_object_size_hint_align_set(comp, EVAS_HINT_FILL, EVAS_HINT_FILL);
diff --git a/src/bin/efl_canvas_wl/meson.build 
b/src/bin/efl_canvas_wl/meson.build
new file mode 100644
index 0000000000..278a2c58db
--- /dev/null
+++ b/src/bin/efl_canvas_wl/meson.build
@@ -0,0 +1,13 @@
+executable('efl_canvas_wl_test',
+  'efl_canvas_wl_test.c',
+  include_directories : config_dir,
+  dependencies: [efl_canvas_wl, efl_canvas_wl_deps, efl_canvas_wl_pub_deps, 
elementary],
+  install: true,
+)
+
+executable('efl_canvas_wl_test_stack',
+  'efl_canvas_wl_test_stack.c',
+  include_directories : config_dir,
+  dependencies: [efl_canvas_wl, efl_canvas_wl_deps, efl_canvas_wl_pub_deps, 
elementary],
+  install: true,
+)
diff --git a/src/bin/efl_wl/meson.build b/src/bin/efl_wl/meson.build
deleted file mode 100644
index dc0f0d248c..0000000000
--- a/src/bin/efl_wl/meson.build
+++ /dev/null
@@ -1,13 +0,0 @@
-executable('efl_wl_test',
-  'efl_wl_test.c',
-  include_directories : config_dir,
-  dependencies: [efl_wl, efl_wl_deps, efl_wl_pub_deps, elementary],
-  install: true,
-)
-
-executable('efl_wl_test_stack',
-  'efl_wl_test_stack.c',
-  include_directories : config_dir,
-  dependencies: [efl_wl, efl_wl_deps, efl_wl_pub_deps, elementary],
-  install: true,
-)
diff --git a/src/lib/efl_wl/copiedfromweston.x 
b/src/lib/efl_canvas_wl/copiedfromweston.x
similarity index 100%
rename from src/lib/efl_wl/copiedfromweston.x
rename to src/lib/efl_canvas_wl/copiedfromweston.x
diff --git a/src/lib/efl_wl/dmabuf.c b/src/lib/efl_canvas_wl/dmabuf.c
similarity index 100%
rename from src/lib/efl_wl/dmabuf.c
rename to src/lib/efl_canvas_wl/dmabuf.c
diff --git a/src/lib/efl_wl/dmabuf.h b/src/lib/efl_canvas_wl/dmabuf.h
similarity index 100%
rename from src/lib/efl_wl/dmabuf.h
rename to src/lib/efl_canvas_wl/dmabuf.h
diff --git a/src/lib/efl_wl/efl_wl.c b/src/lib/efl_canvas_wl/efl_canvas_wl.c
similarity index 97%
rename from src/lib/efl_wl/efl_wl.c
rename to src/lib/efl_canvas_wl/efl_canvas_wl.c
index 060c3837aa..801c3f3fd3 100644
--- a/src/lib/efl_wl/efl_wl.c
+++ b/src/lib/efl_canvas_wl/efl_canvas_wl.c
@@ -39,7 +39,7 @@
 #endif
 #include "Evas_Internal.h"
 #include "canvas/evas_canvas_eo.h"
-#include "Efl_Wl.h"
+#include "Efl_Canvas_Wl.h"
 
 #undef COORDS_INSIDE
 #define COORDS_INSIDE(x, y, xx, yy, ww, hh) \
@@ -88,7 +88,7 @@
                     WL_DATA_DEVICE_MANAGER_DND_ACTION_MOVE | \
                     WL_DATA_DEVICE_MANAGER_DND_ACTION_ASK)
 
-#define MY_CLASS EFL_WL_CLASS
+#define MY_CLASS EFL_CANVAS_WL_CLASS
 
 typedef struct Input_Sequence
 {
@@ -120,7 +120,7 @@ typedef struct Comp_Buffer
 
 typedef struct Comp
 {
-   Efl_Wl_Rotation rotation;
+   Efl_Canvas_Wl_Rotation rotation;
    double scale;
    char *env;
    Efl_Exe_Flags flags;
@@ -2379,18 +2379,18 @@ comp_surface_multi_move(void *data, Evas *e 
EINA_UNUSED, Eo *obj EINA_UNUSED, vo
 }
 
 EOLIAN static Eo *
-_efl_wl_surface_efl_object_constructor(Eo *obj, Comp_Surface *cs EINA_UNUSED)
+_efl_canvas_wl_surface_efl_object_constructor(Eo *obj, Comp_Surface *cs 
EINA_UNUSED)
 {
    efl_canvas_group_clipped_set(obj, EINA_TRUE);
-   return efl_constructor(efl_super(obj, EFL_WL_SURFACE_CLASS));
+   return efl_constructor(efl_super(obj, EFL_CANVAS_WL_SURFACE_CLASS));
 }
 
 static void
-_efl_wl_surface_efl_canvas_group_group_add(Eo *obj, Comp_Surface *cs)
+_efl_canvas_wl_surface_efl_canvas_group_group_add(Eo *obj, Comp_Surface *cs)
 {
    Evas *e;
 
-   efl_canvas_group_add(efl_super(obj, EFL_WL_SURFACE_CLASS));
+   efl_canvas_group_add(efl_super(obj, EFL_CANVAS_WL_SURFACE_CLASS));
    cs->obj = obj;
    evas_object_event_callback_add(cs->obj, EVAS_CALLBACK_MOUSE_DOWN, 
comp_surface_mouse_down, cs);
    evas_object_event_callback_add(cs->obj, EVAS_CALLBACK_MOUSE_UP, 
comp_surface_mouse_up, cs);
@@ -2413,7 +2413,7 @@ _efl_wl_surface_efl_canvas_group_group_add(Eo *obj, 
Comp_Surface *cs)
 }
 
 static void
-_efl_wl_surface_efl_canvas_group_group_del(Eo *obj, Comp_Surface *cs)
+_efl_canvas_wl_surface_efl_canvas_group_group_del(Eo *obj, Comp_Surface *cs)
 {
    array_clear(&cs->input_rects);
    array_clear(&cs->opaque_rects);
@@ -2436,12 +2436,13 @@ _efl_wl_surface_efl_canvas_group_group_del(Eo *obj, 
Comp_Surface *cs)
      }
    cs->c->surfaces = eina_inlist_remove(cs->c->surfaces, EINA_INLIST_GET(cs));
    cs->c->surfaces_count--;
+   efl_canvas_group_del(efl_super(obj, EFL_CANVAS_WL_SURFACE_CLASS));
 }
 
 static void
-_efl_wl_surface_efl_gfx_entity_position_set(Eo *obj, Comp_Surface *cs, 
Eina_Position2D pos)
+_efl_canvas_wl_surface_efl_gfx_entity_position_set(Eo *obj, Comp_Surface *cs, 
Eina_Position2D pos)
 {
-   efl_gfx_entity_position_set(efl_super(obj, EFL_WL_SURFACE_CLASS), pos);
+   efl_gfx_entity_position_set(efl_super(obj, EFL_CANVAS_WL_SURFACE_CLASS), 
pos);
    efl_gfx_entity_position_set(cs->clip, pos);
 
    //{
@@ -2451,9 +2452,9 @@ _efl_wl_surface_efl_gfx_entity_position_set(Eo *obj, 
Comp_Surface *cs, Eina_Posi
 }
 
 static void
-_efl_wl_surface_efl_gfx_entity_size_set(Eo *obj, Comp_Surface *cs, Eina_Size2D 
sz)
+_efl_canvas_wl_surface_efl_gfx_entity_size_set(Eo *obj, Comp_Surface *cs, 
Eina_Size2D sz)
 {
-   efl_gfx_entity_size_set(efl_super(obj, EFL_WL_SURFACE_CLASS), sz);
+   efl_gfx_entity_size_set(efl_super(obj, EFL_CANVAS_WL_SURFACE_CLASS), sz);
    evas_object_resize(cs->clip, sz.w, sz.h);
    //if (cs->cursor) fprintf(stderr, "COMP %sSURFACE(%p) %dx%d\n", 
cs->subsurface ? "SUB" : "", cs, w, h);
    if (cs->drag)
@@ -2461,10 +2462,10 @@ _efl_wl_surface_efl_gfx_entity_size_set(Eo *obj, 
Comp_Surface *cs, Eina_Size2D s
 }
 
 static void
-_efl_wl_surface_efl_gfx_entity_visible_set(Eo *obj, Comp_Surface *cs, 
Eina_Bool vis)
+_efl_canvas_wl_surface_efl_gfx_entity_visible_set(Eo *obj, Comp_Surface *cs, 
Eina_Bool vis)
 {
    Comp_Surface *pcs = NULL, *lcs;
-   efl_gfx_entity_visible_set(efl_super(obj, EFL_WL_SURFACE_CLASS), vis);
+   efl_gfx_entity_visible_set(efl_super(obj, EFL_CANVAS_WL_SURFACE_CLASS), 
vis);
    if (vis)
      {
         evas_object_show(cs->clip);
@@ -2517,9 +2518,9 @@ comp_surface_create(struct wl_client *client, struct 
wl_resource *resource, uint
    int x, y;
 
    res = wl_resource_create(client, &wl_surface_interface, 
wl_resource_get_version(resource), id);
-   obj = efl_add(EFL_WL_SURFACE_CLASS, c->obj);
+   obj = efl_add(EFL_CANVAS_WL_SURFACE_CLASS, c->obj);
    efl_gfx_entity_visible_set(obj, EINA_FALSE);
-   cs = efl_data_scope_get(obj, EFL_WL_SURFACE_CLASS);
+   cs = efl_data_scope_get(obj, EFL_CANVAS_WL_SURFACE_CLASS);
    cs->res = res;
    evas_object_smart_member_add(cs->obj, c->obj);
    cs->c = c;
@@ -3097,16 +3098,16 @@ output_resize(Comp *c, struct wl_resource *res)
    int rot[][4] =
    {
     {
-     [EFL_WL_ROTATION_ROTATE_0] = WL_OUTPUT_TRANSFORM_NORMAL,
-     [EFL_WL_ROTATION_ROTATE_90] = WL_OUTPUT_TRANSFORM_90,
-     [EFL_WL_ROTATION_ROTATE_180] = WL_OUTPUT_TRANSFORM_180,
-     [EFL_WL_ROTATION_ROTATE_270] = WL_OUTPUT_TRANSFORM_270,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_0] = WL_OUTPUT_TRANSFORM_NORMAL,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_90] = WL_OUTPUT_TRANSFORM_90,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_180] = WL_OUTPUT_TRANSFORM_180,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_270] = WL_OUTPUT_TRANSFORM_270,
     },
     {
-     [EFL_WL_ROTATION_ROTATE_0] = WL_OUTPUT_TRANSFORM_FLIPPED,
-     [EFL_WL_ROTATION_ROTATE_90] = WL_OUTPUT_TRANSFORM_FLIPPED_90,
-     [EFL_WL_ROTATION_ROTATE_180] = WL_OUTPUT_TRANSFORM_FLIPPED_180,
-     [EFL_WL_ROTATION_ROTATE_270] = WL_OUTPUT_TRANSFORM_FLIPPED_270,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_0] = WL_OUTPUT_TRANSFORM_FLIPPED,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_90] = WL_OUTPUT_TRANSFORM_FLIPPED_90,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_180] = WL_OUTPUT_TRANSFORM_FLIPPED_180,
+     [EFL_CANVAS_WL_ROTATION_ROTATE_270] = WL_OUTPUT_TRANSFORM_FLIPPED_270,
     },
    };
 
@@ -3173,7 +3174,7 @@ shell_surface_toplevel_set_parent(struct wl_client 
*client EINA_UNUSED, struct w
 
    comp_surface_reparent(cs, pcs);
    if (parent_resource)
-     efl_event_callback_call(cs->c->obj, EFL_WL_EVENT_CHILD_ADDED, cs->obj);
+     efl_event_callback_call(cs->c->obj, EFL_CANVAS_WL_EVENT_CHILD_ADDED, 
cs->obj);
 }
 
 static void
@@ -3267,7 +3268,7 @@ shell_surface_toplevel_create(struct wl_client *client 
EINA_UNUSED, struct wl_re
    cs->role = wl_resource_create(client, &xdg_toplevel_interface, 1, id);
    wl_resource_set_implementation(cs->role, &shell_surface_toplevel_interface, 
cs, shell_surface_toplevel_impl_destroy);
    cs->shell.new = 1;
-   efl_event_callback_call(cs->c->obj, EFL_WL_EVENT_TOPLEVEL_ADDED, cs->obj);
+   efl_event_callback_call(cs->c->obj, EFL_CANVAS_WL_EVENT_TOPLEVEL_ADDED, 
cs->obj);
 }
 
 static void
@@ -3356,7 +3357,7 @@ shell_surface_popup_create(struct wl_client *client, 
struct wl_resource *resourc
      comp_surface_reparent(cs, wl_resource_get_user_data(parent_resource));
    cs->shell.positioner = wl_resource_get_user_data(positioner_resource);
    _apply_positioner(cs, cs->shell.positioner);
-   efl_event_callback_call(cs->c->obj, EFL_WL_EVENT_POPUP_ADDED, cs->obj);
+   efl_event_callback_call(cs->c->obj, EFL_CANVAS_WL_EVENT_POPUP_ADDED, 
cs->obj);
 }
 
 static void
@@ -4472,7 +4473,7 @@ comp_seats_proxy(Comp *c)
         else if (!c->parent_disp)
           comp_device_caps_update(s);
         s->global = wl_global_create(c->display, &wl_seat_interface, 4, s, 
seat_bind);
-        efl_event_callback_call(s->c->obj, EFL_WL_EVENT_SEAT_ADDED, dev);
+        efl_event_callback_call(s->c->obj, EFL_CANVAS_WL_EVENT_SEAT_ADDED, 
dev);
         if (ecore_wl2_display_sync_is_done(c->client_disp))
           seat_proxy_update(s);
      }
@@ -5269,7 +5270,7 @@ efl_hints_bind(struct wl_client *client, void *data, 
uint32_t version, uint32_t
 }
 
 EOLIAN static Eo *
-_efl_wl_efl_object_constructor(Eo *obj, Comp *c)
+_efl_canvas_wl_efl_object_constructor(Eo *obj, Comp *c)
 {
    efl_canvas_group_clipped_set(obj, EINA_TRUE);
    EINA_SAFETY_ON_TRUE_RETURN_VAL(!ecore_wl2_init(), NULL);
@@ -5277,7 +5278,7 @@ _efl_wl_efl_object_constructor(Eo *obj, Comp *c)
 }
 
 EOLIAN static void
-_efl_wl_efl_canvas_group_group_add(Eo *obj, Comp *c)
+_efl_canvas_wl_efl_canvas_group_group_add(Eo *obj, Comp *c)
 {
    char *env, *dbg = NULL;
 
@@ -5288,13 +5289,13 @@ _efl_wl_efl_canvas_group_group_add(Eo *obj, Comp *c)
    env = getenv("WAYLAND_DISPLAY");
    if (env) env = strdup(env);
 
-   if (getenv("EFL_WL_DEBUG"))
+   if (getenv("EFL_CANVAS_WL_DEBUG"))
      {
         dbg = eina_strdup(getenv("WAYLAND_DEBUG"));
         setenv("WAYLAND_DEBUG", "1", 1);
      }
    c->disp = ecore_wl2_display_create(NULL);
-   if (getenv("EFL_WL_DEBUG"))
+   if (getenv("EFL_CANVAS_WL_DEBUG"))
      {
         if (dbg) setenv("WAYLAND_DEBUG", dbg, 1);
         else unsetenv("WAYLAND_DEBUG");
@@ -5366,7 +5367,7 @@ _efl_wl_efl_canvas_group_group_add(Eo *obj, Comp *c)
 }
 
 EOLIAN static void
-_efl_wl_efl_canvas_group_group_del(Eo *obj, Comp *c)
+_efl_canvas_wl_efl_canvas_group_group_del(Eo *obj, Comp *c)
 {
    evas_object_del(c->clip);
    evas_object_del(c->events);
@@ -5411,14 +5412,14 @@ _efl_wl_efl_canvas_group_group_del(Eo *obj, Comp *c)
 }
 
 static void
-_efl_wl_efl_gfx_entity_position_set(Eo *obj, Comp *c, Eina_Position2D pos)
+_efl_canvas_wl_efl_gfx_entity_position_set(Eo *obj, Comp *c, Eina_Position2D 
pos)
 {
    efl_gfx_entity_position_set(efl_super(obj, MY_CLASS), pos);
    efl_gfx_entity_position_set(c->clip, pos);
 }
 
 static void
-_efl_wl_efl_gfx_entity_size_set(Eo *obj, Comp *c, Eina_Size2D sz)
+_efl_canvas_wl_efl_gfx_entity_size_set(Eo *obj, Comp *c, Eina_Size2D sz)
 {
    Eina_List *l;
    Comp_Surface *cs;
@@ -5437,7 +5438,7 @@ _efl_wl_efl_gfx_entity_size_set(Eo *obj, Comp *c, 
Eina_Size2D sz)
 }
 
 static void
-_efl_wl_efl_gfx_entity_visible_set(Eo *obj, Comp *c, Eina_Bool vis)
+_efl_canvas_wl_efl_gfx_entity_visible_set(Eo *obj, Comp *c, Eina_Bool vis)
 {
    Comp_Surface *cs;
 
@@ -5560,25 +5561,25 @@ comp_run(Eo *obj, Comp *c, const char *cmd, 
Efl_Exe_Flags flags)
 }
 
 EOLIAN static Efl_Exe *
-_efl_wl_run(Eo *obj, Comp *c, const char *cmd)
+_efl_canvas_wl_run(Eo *obj, Comp *c, const char *cmd)
 {
    return comp_run(obj, c, cmd, EFL_EXE_FLAGS_TERM_WITH_PARENT);
 }
 
 EOLIAN static Efl_Exe_Flags
-_efl_wl_exec_flags_get(const Eo *obj, Comp *c)
+_efl_canvas_wl_exec_flags_get(const Eo *obj, Comp *c)
 {
    return c->flags;
 }
 
 EOLIAN static void
-_efl_wl_exec_flags_set(Eo *obj, Comp *c, Efl_Exe_Flags flags)
+_efl_canvas_wl_exec_flags_set(Eo *obj, Comp *c, Efl_Exe_Flags flags)
 {
    c->flags = flags;
 }
 
 EOLIAN static void
-_efl_wl_allowed_pid_add(Eo *obj, Comp *c, int32_t pid)
+_efl_canvas_wl_allowed_pid_add(Eo *obj, Comp *c, int32_t pid)
 {
    if (!c->exes)
      c->exes = eina_hash_int32_new(NULL);
@@ -5586,14 +5587,14 @@ _efl_wl_allowed_pid_add(Eo *obj, Comp *c, int32_t pid)
 }
 
 EOLIAN static void
-_efl_wl_allowed_pid_del(Eo *obj, Comp *c, int32_t pid)
+_efl_canvas_wl_allowed_pid_del(Eo *obj, Comp *c, int32_t pid)
 {
    if (!c->exes) return;
    eina_hash_del_by_key(c->exes, &pid);
 }
 
 EOLIAN static Eo *
-_efl_wl_surface_next(Eo *obj, Comp *c)
+_efl_canvas_wl_surface_next(Eo *obj, Comp *c)
 {
    Comp_Surface *cs;
 
@@ -5611,7 +5612,7 @@ _efl_wl_surface_next(Eo *obj, Comp *c)
 }
 
 EOLIAN static Eo *
-_efl_wl_surface_prev(Eo *obj, Comp *c)
+_efl_canvas_wl_surface_prev(Eo *obj, Comp *c)
 {
    Comp_Surface *cs;
 
@@ -5629,7 +5630,7 @@ _efl_wl_surface_prev(Eo *obj, Comp *c)
 }
 
 EOLIAN static Eo *
-_efl_wl_active_surface_get(const Eo *obj, Comp *c)
+_efl_canvas_wl_active_surface_get(const Eo *obj, Comp *c)
 {
    if (c->active_surface && (!c->active_surface->dead))
      return c->active_surface->obj;
@@ -5637,9 +5638,9 @@ _efl_wl_active_surface_get(const Eo *obj, Comp *c)
 }
 
 EOLIAN static Eina_Bool
-_efl_wl_active_surface_set(Eo *obj, Comp *c, Eo *surface)
+_efl_canvas_wl_active_surface_set(Eo *obj, Comp *c, Eo *surface)
 {
-   Comp_Surface *cs = efl_data_scope_get(surface, EFL_WL_SURFACE_CLASS);
+   Comp_Surface *cs = efl_data_scope_get(surface, EFL_CANVAS_WL_SURFACE_CLASS);
    EINA_SAFETY_ON_NULL_RETURN_VAL(cs, EINA_FALSE);
    if (cs->dead) return EINA_FALSE;
    if (c->active_surface == cs) return EINA_TRUE;
@@ -5651,14 +5652,14 @@ _efl_wl_active_surface_set(Eo *obj, Comp *c, Eo 
*surface)
 }
 
 EOLIAN static void
-_efl_wl_rotation_get(const Eo *obj EINA_UNUSED, Comp *c, Efl_Wl_Rotation 
*rotation, Eina_Bool *rtl)
+_efl_canvas_wl_rotation_get(const Eo *obj EINA_UNUSED, Comp *c, 
Efl_Canvas_Wl_Rotation *rotation, Eina_Bool *rtl)
 {
    if (rotation) *rotation = c->rotation;
    if (rtl) *rtl = c->rtl;
 }
 
 EOLIAN static void
-_efl_wl_rotation_set(Eo *obj EINA_UNUSED, Comp *c, Efl_Wl_Rotation rot, 
Eina_Bool rtl)
+_efl_canvas_wl_rotation_set(Eo *obj EINA_UNUSED, Comp *c, 
Efl_Canvas_Wl_Rotation rot, Eina_Bool rtl)
 {
    Eina_List *l;
    struct wl_resource *res;
@@ -5670,13 +5671,13 @@ _efl_wl_rotation_set(Eo *obj EINA_UNUSED, Comp *c, 
Efl_Wl_Rotation rot, Eina_Boo
 }
 
 EOLIAN static double
-_efl_wl_efl_gfx_entity_scale_get(const Eo *obj EINA_UNUSED, Comp *c)
+_efl_canvas_wl_efl_gfx_entity_scale_get(const Eo *obj EINA_UNUSED, Comp *c)
 {
    return c->scale;
 }
 
 EOLIAN static void
-_efl_wl_efl_gfx_entity_scale_set(Eo *obj EINA_UNUSED, Comp *c, double scale)
+_efl_canvas_wl_efl_gfx_entity_scale_set(Eo *obj EINA_UNUSED, Comp *c, double 
scale)
 {
    Eina_List *l;
    struct wl_resource *res;
@@ -5689,13 +5690,13 @@ _efl_wl_efl_gfx_entity_scale_set(Eo *obj EINA_UNUSED, 
Comp *c, double scale)
 }
 
 EOLIAN static Eina_Bool
-_efl_wl_aspect_get(const Eo *obj EINA_UNUSED, Comp *c)
+_efl_canvas_wl_aspect_get(const Eo *obj EINA_UNUSED, Comp *c)
 {
    return c->aspect;
 }
 
 EOLIAN static void
-_efl_wl_aspect_set(Eo *obj, Comp *c, Eina_Bool set)
+_efl_canvas_wl_aspect_set(Eo *obj, Comp *c, Eina_Bool set)
 {
    if (c->aspect == (!!set)) return;
    c->aspect = !!set;
@@ -5706,13 +5707,13 @@ _efl_wl_aspect_set(Eo *obj, Comp *c, Eina_Bool set)
 }
 
 EOLIAN static Eina_Bool
-_efl_wl_minmax_get(const Eo *obj EINA_UNUSED, Comp *c)
+_efl_canvas_wl_minmax_get(const Eo *obj EINA_UNUSED, Comp *c)
 {
    return c->minmax;
 }
 
 EOLIAN static void
-_efl_wl_minmax_set(Eo *obj, Comp *c, Eina_Bool set)
+_efl_canvas_wl_minmax_set(Eo *obj, Comp *c, Eina_Bool set)
 {
    if (c->minmax == (!!set)) return;
    c->minmax = !!set;
@@ -5725,8 +5726,8 @@ _efl_wl_minmax_set(Eo *obj, Comp *c, Eina_Bool set)
      }
 }
 
-EOLIAN static Efl_Wl_Wl_Global *
-_efl_wl_global_add(Eo *obj, Comp *c, const Efl_Wl_Wl_Interface *interface, 
uint32_t version, Efl_Wl_Wl_Interface_Data *data, Efl_Wl_Wl_Interface_Bind_Cb 
*bind_cb)
+EOLIAN static Efl_Canvas_Wl_Wl_Global *
+_efl_canvas_wl_global_add(Eo *obj, Comp *c, const Efl_Canvas_Wl_Wl_Interface 
*interface, uint32_t version, Efl_Canvas_Wl_Wl_Interface_Data *data, 
Efl_Canvas_Wl_Wl_Interface_Bind_Cb *bind_cb)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(interface, NULL);
    return (void*)wl_global_create(c->display, (void*)interface, version, 
(void*)data, (void*)bind_cb);
@@ -5769,7 +5770,7 @@ extracted_changed(void *data, Evas *e EINA_UNUSED, Eo 
*obj, void *event_info EIN
 }
 
 static EOLIAN int32_t
-_efl_wl_surface_pid_get(const Eo *surface, Comp_Surface *cs)
+_efl_canvas_wl_surface_pid_get(const Eo *surface, Comp_Surface *cs)
 {
    int32_t pid;
    EINA_SAFETY_ON_TRUE_RETURN_VAL(cs->dead, -1);
@@ -5778,7 +5779,7 @@ _efl_wl_surface_pid_get(const Eo *surface, Comp_Surface 
*cs)
 }
 
 static EOLIAN Eina_Bool
-_efl_wl_surface_extract(Eo *surface, Comp_Surface *cs)
+_efl_canvas_wl_surface_extract(Eo *surface, Comp_Surface *cs)
 {
    EINA_SAFETY_ON_TRUE_RETURN_VAL(cs->extracted, EINA_FALSE);
    EINA_SAFETY_ON_TRUE_RETURN_VAL(cs->dead, EINA_FALSE);
@@ -5792,7 +5793,7 @@ _efl_wl_surface_extract(Eo *surface, Comp_Surface *cs)
 }
 
 Eo *
-efl_wl_extracted_surface_object_find(void *surface_resource)
+efl_canvas_wl_extracted_surface_object_find(void *surface_resource)
 {
    Comp_Surface *cs = wl_resource_get_user_data(surface_resource);
 
@@ -5804,7 +5805,7 @@ efl_wl_extracted_surface_object_find(void 
*surface_resource)
 }
 
 static EOLIAN Eo *
-_efl_wl_surface_parent_surface_get(const Eo *surface, Comp_Surface *cs)
+_efl_canvas_wl_surface_parent_surface_get(const Eo *surface, Comp_Surface *cs)
 {
    EINA_SAFETY_ON_TRUE_RETURN_VAL(cs->dead, NULL);
 
@@ -5813,13 +5814,13 @@ _efl_wl_surface_parent_surface_get(const Eo *surface, 
Comp_Surface *cs)
 }
 
 static EOLIAN void
-_efl_wl_seat_keymap_set(Eo *obj, Comp *c, Eo *seat, Efl_Wl_Xkb_State *state, 
const char *str, Efl_Wl_Wl_Array *key_array)
+_efl_canvas_wl_seat_keymap_set(Eo *obj, Comp *c, Eo *seat, 
Efl_Canvas_Wl_Xkb_State *state, const char *str, Efl_Canvas_Wl_Wl_Array 
*key_array)
 {
    Comp_Seat *s;
 
    EINA_INLIST_FOREACH(c->seats, s)
      {
-        if (!seat) efl_wl_seat_keymap_set(obj, s->dev, state, str, key_array);
+        if (!seat) efl_canvas_wl_seat_keymap_set(obj, s->dev, state, str, 
key_array);
         else if (s->dev == seat) break;
      }
    if (!seat) return;
@@ -5840,13 +5841,13 @@ _efl_wl_seat_keymap_set(Eo *obj, Comp *c, Eo *seat, 
Efl_Wl_Xkb_State *state, con
 }
 
 static EOLIAN void
-_efl_wl_seat_key_repeat_set(Eo *obj, Comp *c, Eo *seat, int repeat_rate, int 
repeat_delay)
+_efl_canvas_wl_seat_key_repeat_set(Eo *obj, Comp *c, Eo *seat, int 
repeat_rate, int repeat_delay)
 {
    Comp_Seat *s;
 
    EINA_INLIST_FOREACH(c->seats, s)
      {
-        if (!seat) efl_wl_seat_key_repeat_set(obj, s->dev, repeat_rate, 
repeat_delay);
+        if (!seat) efl_canvas_wl_seat_key_repeat_set(obj, s->dev, repeat_rate, 
repeat_delay);
         else if (s->dev == seat) break;
      }
    if (!seat) return;
@@ -5856,11 +5857,11 @@ _efl_wl_seat_key_repeat_set(Eo *obj, Comp *c, Eo *seat, 
int repeat_rate, int rep
    seat_kbd_repeat_rate_send(s);
 }
 
-#define EFL_WL_EXTRA_OPS \
-  EFL_CANVAS_GROUP_ADD_DEL_OPS(efl_wl), \
+#define EFL_CANVAS_WL_EXTRA_OPS \
+  EFL_CANVAS_GROUP_ADD_DEL_OPS(efl_canvas_wl), \
 
-#define EFL_WL_SURFACE_EXTRA_OPS \
-  EFL_CANVAS_GROUP_ADD_DEL_OPS(efl_wl_surface), \
+#define EFL_CANVAS_WL_SURFACE_EXTRA_OPS \
+  EFL_CANVAS_GROUP_ADD_DEL_OPS(efl_canvas_wl_surface), \
 
-#include "efl_wl.eo.c"
-#include "efl_wl_surface.eo.c"
+#include "efl_canvas_wl.eo.c"
+#include "efl_canvas_wl_surface.eo.c"
diff --git a/src/lib/efl_wl/efl_wl.eo b/src/lib/efl_canvas_wl/efl_canvas_wl.eo
similarity index 55%
rename from src/lib/efl_wl/efl_wl.eo
rename to src/lib/efl_canvas_wl/efl_canvas_wl.eo
index f52fa1a8c6..9924ce9a1f 100644
--- a/src/lib/efl_wl/efl_wl.eo
+++ b/src/lib/efl_canvas_wl/efl_canvas_wl.eo
@@ -1,17 +1,17 @@
 import efl_exe;
 import efl_input_device;
-import efl_wl_surface;
+import efl_canvas_wl_surface;
 
-struct @beta @extern Efl.Wl_Wl_Surface; [[ struct wl_surface. @since 1.24 ]]
-struct @beta @extern Efl.Wl_Wl_Global; [[ struct wl_global. @since 1.24 ]]
-struct @beta @extern Efl.Wl_Wl_Interface; [[ A libwayland callback interface 
struct. @since 1.24 ]]
-struct @beta @extern Efl.Wl_Wl_Interface_Data; [[ A data pointer to send with 
the bind callback. @since 1.24 ]]
-struct @beta @extern Efl.Wl_Wl_Interface_Bind_Cb; [[ A callback with the type 
(*void)(struct wl_client *client, void *data, uint32_t version, uint32_t id). 
@since 1.24 ]]
-struct @beta @extern Efl.Wl_Xkb_State; [[ struct xkb_state. @since 1.24 ]]
-struct @beta @extern Efl.Wl_Wl_Array; [[ struct wl_array. @since 1.24 ]]
+struct @beta @extern Efl.Canvas.Wl_Wl_Surface; [[ struct wl_surface. @since 
1.24 ]]
+struct @beta @extern Efl.Canvas.Wl_Wl_Global; [[ struct wl_global. @since 1.24 
]]
+struct @beta @extern Efl.Canvas.Wl_Wl_Interface; [[ A libwayland callback 
interface struct. @since 1.24 ]]
+struct @beta @extern Efl.Canvas.Wl_Wl_Interface_Data; [[ A data pointer to 
send with the bind callback. @since 1.24 ]]
+struct @beta @extern Efl.Canvas.Wl_Wl_Interface_Bind_Cb; [[ A callback with 
the type (*void)(struct wl_client *client, void *data, uint32_t version, 
uint32_t id). @since 1.24 ]]
+struct @beta @extern Efl.Canvas.Wl_Xkb_State; [[ struct xkb_state. @since 1.24 
]]
+struct @beta @extern Efl.Canvas.Wl_Wl_Array; [[ struct wl_array. @since 1.24 ]]
 
 
-enum @beta Efl.Wl.Rotation
+enum @beta Efl.Canvas.Wl.Rotation
 {
    [[Orientation of the internal compositor object in degrees. These values 
are COUNTER-CLOCKWISE.
    ]]
@@ -21,7 +21,7 @@ enum @beta Efl.Wl.Rotation
    rotate_270 = 3
 }
 
-class @beta Efl.Wl extends Efl.Canvas.Group
+class @beta Efl.Canvas.Wl extends Efl.Canvas.Group
 {
    [[
      @since 1.24
@@ -52,10 +52,10 @@ class @beta Efl.Wl extends Efl.Canvas.Group
          }
       }
       surface_next {
-         return: Efl.Wl.Surface;
+         return: Efl.Canvas.Wl.Surface;
       }
       surface_prev {
-         return: Efl.Wl.Surface;
+         return: Efl.Canvas.Wl.Surface;
       }
       @property active_surface {
          get {}
@@ -63,7 +63,7 @@ class @beta Efl.Wl extends Efl.Canvas.Group
             return: bool;
          }
          values {
-            surface: Efl.Wl.Surface;
+            surface: Efl.Canvas.Wl.Surface;
          }
       }
       @property aspect {
@@ -78,25 +78,25 @@ class @beta Efl.Wl extends Efl.Canvas.Group
       }
       @property rotation {
          values {
-            rotation: Efl.Wl.Rotation;
+            rotation: Efl.Canvas.Wl.Rotation;
             rtl: bool;
          }
       }
       global_add {
          params {
-            interface: const(Efl.Wl_Wl_Interface) @by_ref;
+            interface: const(Efl.Canvas.Wl_Wl_Interface) @by_ref;
             version: uint;
-            data: Efl.Wl_Wl_Interface_Data @by_ref;
-            bind_cb: Efl.Wl_Wl_Interface_Bind_Cb @by_ref;
+            data: Efl.Canvas.Wl_Wl_Interface_Data @by_ref;
+            bind_cb: Efl.Canvas.Wl_Wl_Interface_Bind_Cb @by_ref;
          }
-         return: Efl.Wl_Wl_Global @by_ref;
+         return: Efl.Canvas.Wl_Wl_Global @by_ref;
       }
       seat_keymap_set {
          params {
             seat: Efl.Input.Device;
-            state: Efl.Wl_Xkb_State @by_ref;
+            state: Efl.Canvas.Wl_Xkb_State @by_ref;
             keymap_str: string;
-            key_array: Efl.Wl_Wl_Array @by_ref;
+            key_array: Efl.Canvas.Wl_Wl_Array @by_ref;
          }
       }
       seat_key_repeat_set {
@@ -115,9 +115,9 @@ class @beta Efl.Wl extends Efl.Canvas.Group
       Efl.Gfx.Entity.scale { get; set; }
    }
    events {
-      toplevel,added: Efl.Wl.Surface; [[]]
-      child,added: Efl.Wl.Surface; [[]]
-      popup,added: Efl.Wl.Surface; [[]]
+      toplevel,added: Efl.Canvas.Wl.Surface; [[]]
+      child,added: Efl.Canvas.Wl.Surface; [[]]
+      popup,added: Efl.Canvas.Wl.Surface; [[]]
       seat,added: Efl.Input.Device; [[The seat object added.]]
    }
 }
diff --git a/src/lib/efl_wl/efl_wl_surface.eo 
b/src/lib/efl_canvas_wl/efl_canvas_wl_surface.eo
similarity index 81%
rename from src/lib/efl_wl/efl_wl_surface.eo
rename to src/lib/efl_canvas_wl/efl_canvas_wl_surface.eo
index 65c7327c95..d93e7d1ce6 100644
--- a/src/lib/efl_wl/efl_wl_surface.eo
+++ b/src/lib/efl_canvas_wl/efl_canvas_wl_surface.eo
@@ -1,4 +1,4 @@
-class @beta Efl.Wl.Surface extends Efl.Canvas.Group
+class @beta Efl.Canvas.Wl.Surface extends Efl.Canvas.Group
 {
    [[@since 1.24]]
    data: Comp_Surface;
@@ -15,7 +15,7 @@ class @beta Efl.Wl.Surface extends Efl.Canvas.Group
       @property parent_surface {
          get {}
          values {
-            parent: Efl.Wl.Surface;
+            parent: Efl.Canvas.Wl.Surface;
          }
       }
    }
diff --git a/src/lib/efl_wl/meson.build b/src/lib/efl_canvas_wl/meson.build
similarity index 56%
rename from src/lib/efl_wl/meson.build
rename to src/lib/efl_canvas_wl/meson.build
index ca1a082e36..d021975844 100644
--- a/src/lib/efl_wl/meson.build
+++ b/src/lib/efl_canvas_wl/meson.build
@@ -1,14 +1,14 @@
-efl_wl_deps = [ecore_wl2, ecore_input, ecore, ecore_evas, evas, emile, eina]
-efl_wl_pub_deps = [eo, efl, evas, dependency('wayland-server', version : '>= 
1.11.0'), dependency('xkbcommon', version : '>= 0.6.0')]
+efl_canvas_wl_deps = [ecore_wl2, ecore_input, ecore, ecore_evas, evas, emile, 
eina]
+efl_canvas_wl_pub_deps = [eo, efl, evas, dependency('wayland-server', version 
: '>= 1.11.0'), dependency('xkbcommon', version : '>= 0.6.0')]
 
 if (get_option('x11'))
-  efl_wl_deps += [ecore_x]
-  efl_wl_pub_deps += [dependency('xkbcommon-x11')]
+  efl_canvas_wl_deps += [ecore_x]
+  efl_canvas_wl_pub_deps += [dependency('xkbcommon-x11')]
 endif
 
 pub_eo_files = [
- 'efl_wl.eo',
- 'efl_wl_surface.eo',
+ 'efl_canvas_wl.eo',
+ 'efl_canvas_wl_surface.eo',
 ]
 
 foreach eo_file : pub_eo_files
@@ -25,36 +25,36 @@ foreach eo_file : pub_eo_files
                            '-gchd', '@INPUT@'])
 endforeach
 
-efl_wl_src = [
+efl_canvas_wl_src = [
  'dmabuf.c',
- 'efl_wl.c',
+ 'efl_canvas_wl.c',
 ]
-efl_wl_header_src = ['Efl_Wl.h']
+efl_canvas_wl_header_src = ['Efl_Canvas_Wl.h']
 eolian_include_directories += ['-I', meson.current_source_dir()]
 
-efl_wl_lib = library('efl_wl',
-    efl_wl_src, pub_eo_file_target,
-    dependencies: [m, dl] + efl_wl_deps + efl_wl_pub_deps,
+efl_canvas_wl_lib = library('efl_canvas_wl',
+    efl_canvas_wl_src, pub_eo_file_target,
+    dependencies: [m, dl] + efl_canvas_wl_deps + efl_canvas_wl_pub_deps,
     include_directories : config_dir + 
[include_directories(join_paths('..','..'))],
     install: true,
     c_args : package_c_args,
     version : meson.project_version()
 )
 
-efl_wl = declare_dependency(
+efl_canvas_wl = declare_dependency(
   include_directories: [include_directories('.')],
-  link_with: efl_wl_lib,
+  link_with: efl_canvas_wl_lib,
   sources: pub_eo_file_target,
-  dependencies: efl_wl_pub_deps,
+  dependencies: efl_canvas_wl_pub_deps,
 )
 
-install_headers(efl_wl_header_src,
+install_headers(efl_canvas_wl_header_src,
   install_dir : dir_package_include,
 )
 
-eolian_efl_wl_dir = join_paths(eolian_include_dir, package_version_name)
+eolian_efl_canvas_wl_dir = join_paths(eolian_include_dir, package_version_name)
 if get_option('install-eo-files')
   install_data(pub_eo_files,
-    install_dir: eolian_efl_wl_dir
+    install_dir: eolian_efl_canvas_wl_dir
   )
 endif
diff --git a/src/lib/efl_wl/Efl_Wl.h b/src/lib/efl_canvas_wl/Efl_Canvas_Wl.h
similarity index 73%
rename from src/lib/efl_wl/Efl_Wl.h
rename to src/lib/efl_canvas_wl/Efl_Canvas_Wl.h
index d24557dc1a..b62f0de729 100644
--- a/src/lib/efl_wl/Efl_Wl.h
+++ b/src/lib/efl_canvas_wl/Efl_Canvas_Wl.h
@@ -1,5 +1,5 @@
-#ifndef EFL_WL_H
-# define EFL_WL_H
+#ifndef EFL_CANVAS_WL_H
+# define EFL_CANVAS_WL_H
 #include <Evas.h>
 #include <Efl_Core.h>
 
@@ -23,16 +23,16 @@
 #define EWAPI EAPI EAPI_WEAK
 
 
-typedef struct Efl_Wl_Wl_Surface Efl_Wl_Wl_Surface;
-typedef struct Efl_Wl_Wl_Global Efl_Wl_Wl_Global;
-typedef struct Efl_Wl_Wl_Interface Efl_Wl_Wl_Interface;
-typedef struct Efl_Wl_Wl_Array Efl_Wl_Wl_Array;
-typedef void * Efl_Wl_Wl_Interface_Data;
-typedef void * Efl_Wl_Wl_Interface_Bind_Cb;
-typedef struct Efl_Wl_Xkb_State Efl_Wl_Xkb_State;
+typedef struct Efl_Canvas_Wl_Wl_Surface Efl_Canvas_Wl_Wl_Surface;
+typedef struct Efl_Canvas_Wl_Wl_Global Efl_Canvas_Wl_Wl_Global;
+typedef struct Efl_Canvas_Wl_Wl_Interface Efl_Canvas_Wl_Wl_Interface;
+typedef struct Efl_Canvas_Wl_Wl_Array Efl_Canvas_Wl_Wl_Array;
+typedef void * Efl_Canvas_Wl_Wl_Interface_Data;
+typedef void * Efl_Canvas_Wl_Wl_Interface_Bind_Cb;
+typedef struct Efl_Canvas_Wl_Xkb_State Efl_Canvas_Wl_Xkb_State;
 
-#include <efl_wl_surface.eo.h>
-#include <efl_wl.eo.h>
+#include <efl_canvas_wl_surface.eo.h>
+#include <efl_canvas_wl.eo.h>
 /**
  * @defgroup Efl_Wl_Group EFL Wayland
  *
@@ -54,7 +54,7 @@ typedef struct Efl_Wl_Xkb_State Efl_Wl_Xkb_State;
  * @param e The canvas
  * @return The compositor object, @c NULL on failure
  */
-EAPI Evas_Object *efl_wl_add(Evas *e);
+EAPI Evas_Object *efl_canvas_wl_add(Evas *e);
 
 /**
  * Run a command in the compositor widget.
@@ -66,7 +66,7 @@ EAPI Evas_Object *efl_wl_add(Evas *e);
  * @param cmd The command to run
  * @return The Ecore_Exe from the executed process, @c NULL on failure
  */
-EAPI Ecore_Exe *efl_wl_run(Evas_Object *obj, const char *cmd);
+EAPI Ecore_Exe *efl_canvas_wl_run(Evas_Object *obj, const char *cmd);
 
 /**
  * Run a command in the compositor widget with specified flags.
@@ -79,7 +79,7 @@ EAPI Ecore_Exe *efl_wl_run(Evas_Object *obj, const char *cmd);
  * @param flags The flags to use
  * @return The Ecore_Exe from the executed process, @c NULL on failure
  */
-Ecore_Exe *efl_wl_flags_run(Evas_Object *obj, const char *cmd, Ecore_Exe_Flags 
flags);
+Ecore_Exe *efl_canvas_wl_flags_run(Evas_Object *obj, const char *cmd, 
Ecore_Exe_Flags flags);
 
 /**
  * Add a process to the list of allowed clients for the compositor widget
@@ -88,7 +88,7 @@ Ecore_Exe *efl_wl_flags_run(Evas_Object *obj, const char 
*cmd, Ecore_Exe_Flags f
  * @param pid The process to allow
  * @since 1.21
  */
-EAPI void efl_wl_pid_add(Evas_Object *obj, int32_t pid);
+EAPI void efl_canvas_wl_pid_add(Evas_Object *obj, int32_t pid);
 
 /**
  * Remove a process from the list of allowed clients for the compositor widget
@@ -97,7 +97,7 @@ EAPI void efl_wl_pid_add(Evas_Object *obj, int32_t pid);
  * @param pid The process to deny
  * @since 1.21
  */
-EAPI void efl_wl_pid_del(Evas_Object *obj, int32_t pid);
+EAPI void efl_canvas_wl_pid_del(Evas_Object *obj, int32_t pid);
 
 /**
  * Put the bottom-most toplevel window on top and apply focus to it
@@ -105,7 +105,7 @@ EAPI void efl_wl_pid_del(Evas_Object *obj, int32_t pid);
  * @param obj The compositor widget
  * @return EINA_TRUE if the window stacking was changed
  */
-EAPI Eina_Bool efl_wl_surface_next(Evas_Object *obj);
+EAPI Eina_Bool efl_canvas_wl_surface_next(Evas_Object *obj);
 
 /**
  * Put the second top-most toplevel window on top and apply focus to it
@@ -113,7 +113,7 @@ EAPI Eina_Bool efl_wl_surface_next(Evas_Object *obj);
  * @param obj The compositor widget
  * @return EINA_TRUE if the window stacking was changed
  */
-EAPI Eina_Bool efl_wl_surface_prev(Evas_Object *obj);
+EAPI Eina_Bool efl_canvas_wl_surface_prev(Evas_Object *obj);
 
 /**
  * Set rotation and flip for the compositor's output
@@ -124,7 +124,7 @@ EAPI Eina_Bool efl_wl_surface_prev(Evas_Object *obj);
  * @note rtl is equivalent to WL_OUTPUT_TRANSFORM_FLIPPED and rotations are 
applied
  * on top
  */
-EAPI void efl_wl_rotate(Evas_Object *obj, Efl_Wl_Rotation rot, Eina_Bool rtl);
+EAPI void efl_canvas_wl_rotate(Evas_Object *obj, Efl_Wl_Rotation rot, 
Eina_Bool rtl);
 
 /**
  * Set the scale factor for the compositor's output
@@ -132,25 +132,25 @@ EAPI void efl_wl_rotate(Evas_Object *obj, Efl_Wl_Rotation 
rot, Eina_Bool rtl);
  * @param obj The compositor widget
  * @param scale The scale factor to set
  */
-EAPI void efl_wl_scale_set(Evas_Object *obj, double scale);
+EAPI void efl_canvas_wl_scale_set(Evas_Object *obj, double scale);
 
 /**
  * Transfer aspect hints from top-most surface onto the efl_wl object
  *
  * @param obj The compositor widget
  * @param set Whether to enable aspect setting
  * @since 1.21
  */
-EAPI void efl_wl_aspect_set(Evas_Object *obj, Eina_Bool set);
+EAPI void efl_canvas_wl_aspect_set(Evas_Object *obj, Eina_Bool set);
 
 /**
  * Transfer min/max hints from top-most surface onto the efl_wl object
  *
  * @param obj The compositor widget
  * @param set Whether to enable min/max setting
  * @since 1.21
  */
-EAPI void efl_wl_minmax_set(Evas_Object *obj, Eina_Bool set);
+EAPI void efl_canvas_wl_minmax_set(Evas_Object *obj, Eina_Bool set);
 
 /**
  * Add an externally-managed global to the compositor
@@ -166,7 +166,7 @@ EAPI void efl_wl_minmax_set(Evas_Object *obj, Eina_Bool 
set);
  * @return The created global (struct wl_global), or NULL on failure
  * @since 1.21
  */
-EAPI void *efl_wl_global_add(Evas_Object *obj, const void *interface, uint32_t 
version, void *data, void *bind_cb);
+EAPI void *efl_canvas_wl_global_add(Evas_Object *obj, const void *interface, 
uint32_t version, void *data, void *bind_cb);
 
 /**
  * Extract a child surface from the compositor
@@ -178,7 +178,7 @@ EAPI void *efl_wl_global_add(Evas_Object *obj, const void 
*interface, uint32_t v
  * @return True if the surface was successfully extracted
  * @since 1.21
  */
-EAPI Eina_Bool efl_wl_surface_extract(Evas_Object *surface);
+EAPI Eina_Bool efl_canvas_wl_surface_extract(Evas_Object *surface);
 
 /**
  * Return the pid for the surface's client
@@ -189,18 +189,18 @@ EAPI Eina_Bool efl_wl_surface_extract(Evas_Object 
*surface);
  * @return The pid of the surface, or -1 on failure
  * @since 1.24
  */
-EAPI int32_t efl_wl_surface_pid_get(Evas_Object *surface);
+EAPI int32_t efl_canvas_wl_surface_pid_get(Evas_Object *surface);
 #endif
 /**
- * Get the Evas_Object for an extracted wl_surface resource created by an 
efl_wl object
+ * Get the Evas_Object for an extracted wl_surface resource created by an 
efl_canvas_wl object
  *
- * @note Passing anything other than a valid wl_surface resource from an 
efl_wl object will guarantee a crash.
+ * @note Passing anything other than a valid wl_surface resource from an 
efl_canvas_wl object will guarantee a crash.
  *
  * @param surface_resource The wl_resource for a wl_surface
  * @return The Evas_Object of the surface, NULL on failure
  * @since 1.21
  */
-EAPI Evas_Object *efl_wl_extracted_surface_object_find(void *surface_resource);
+EAPI Evas_Object *efl_canvas_wl_extracted_surface_object_find(void 
*surface_resource);
 #if 0
 /**
  * Get the Evas_Object for an extracted surface's parent, or NULL if the 
parent is not extracted
@@ -211,7 +211,7 @@ EAPI Evas_Object *efl_wl_extracted_surface_object_find(void 
*surface_resource);
  * @return The Evas_Object of the parent surface, NULL on failure or if there 
is no parent
  * @since 1.21
  */
-EAPI Evas_Object *efl_wl_extracted_surface_extracted_parent_get(Evas_Object 
*surface);
+EAPI Evas_Object 
*efl_canvas_wl_extracted_surface_extracted_parent_get(Evas_Object *surface);
 
 /**
  * Set external xkbcommon resources to be used read-only by the compositor 
object
@@ -229,7 +229,7 @@ EAPI Evas_Object 
*efl_wl_extracted_surface_extracted_parent_get(Evas_Object *sur
  * @param wl_key_array A pointer to the wl_array in which keys are stored
  * @since 1.21
  */
-EAPI void efl_wl_seat_keymap_set(Evas_Object *obj, Eo *seat, void *state, char 
*str, void *wl_key_array);
+EAPI void efl_canvas_wl_seat_keymap_set(Evas_Object *obj, Eo *seat, void 
*state, char *str, void *wl_key_array);
 
 /**
  * Set the key repeat rate for a seat in the compositor
@@ -237,7 +237,7 @@ EAPI void efl_wl_seat_keymap_set(Evas_Object *obj, Eo 
*seat, void *state, char *
  * @param obj The compositor widget
  * @since 1.21
  */
-EAPI void efl_wl_seat_key_repeat_set(Evas_Object *obj, Eo *seat, int 
repeat_rate, int repeat_delay);
+EAPI void efl_canvas_wl_seat_key_repeat_set(Evas_Object *obj, Eo *seat, int 
repeat_rate, int repeat_delay);
 #endif
 #undef EAPI
@@ -132,25 +132,25 @@ EAPI void efl_wl_rotate(Evas_Object *obj, Efl_Wl_Rotation 
 
 /**
- * Transfer aspect hints from top-most surface onto the efl_wl object
+ * Transfer aspect hints from top-most surface onto the efl_canvas_wl object
  *
  * @param obj The compositor widget
@@ -132,25 +132,25 @@ EAPI void efl_wl_rotate(Evas_Object *obj, Efl_Wl_Rotation 
 
 /**
- * Transfer min/max hints from top-most surface onto the efl_wl object
+ * Transfer min/max hints from top-most surface onto the efl_canvas_wl object
  *
  * @param obj The compositor widget
 #define EAPI
diff --git a/src/lib/efl_wl/x11.x b/src/lib/efl_canvas_wl/x11.x
similarity index 100%
rename from src/lib/efl_wl/x11.x
rename to src/lib/efl_canvas_wl/x11.x

-- 


Reply via email to